@@ -4,22 +4,20 @@
 const QString iconSilent = "/usr/share/icons/hicolor/48x48/hildon/statusarea_silent.png";
 const QString iconGeneral = "/usr/share/icons/hicolor/48x48/hildon/statusarea_volumelevel4.png";
 
-ProfileChangerWidget::ProfileChangerWidget(QWidget *parent) :
-    QWidget(parent),
+ProfileChangerWidget::ProfileChangerWidget (QWidget *parent) :
+QMainWindow(parent),
     ui(new Ui::ProfileChangerWidget)
 {
-    qWarning("profile-changer-widget.cpp setupui");
     ui->setupUi(this);
-//    this->setAttribute(Qt::WA_TranslucentBackground);
-//    if (!QSettings().contains("profilechangerwidget/width"))
-//        QSettings().setValue("profilechangerwidget/width", 48);
-//    if (!QSettings().contains("profilechangerwidget/height"))
-//        QSettings().setValue("profilechangerwidget/height", 48);
+    setAttribute(Qt::WA_TranslucentBackground);
+    if (!QSettings().contains("profilechangerwidget/width"))
+        QSettings().setValue("profilechangerwidget/width", 48);
+    if (!QSettings().contains("profilechangerwidget/height"))
+        QSettings().setValue("profilechangerwidget/height", 48);
 
-//    qWarning("profile-changer-widget connect onChangeProfileClicked");
-//    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
-//    qWarning("profile-changer-widget connect reload");
-//    this->reloadSettings();
+    connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
+    ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
+    this->reloadSettings();
 }
 
 ProfileChangerWidget::~ProfileChangerWidget()
@@ -35,7 +33,7 @@ QString ProfileChangerWidget::getProfileName() {
         "com.nokia.profiled", // message name (w/o method)
         "get_profile" // method
     );
-    msg = QDBusConnection::systemBus().call(msg);
+    msg = QDBusConnection::sessionBus().call(msg);
 
     if (msg.type() == QDBusMessage::ErrorMessage) {
         QErrorMessage* err = new QErrorMessage();
@@ -54,7 +52,7 @@ void ProfileChangerWidget::setProfile(QString profileName) {
         "set_profile" // method
     );
     msg << profileName;
-    msg = QDBusConnection::systemBus().call(msg);
+    msg = QDBusConnection::sessionBus().call(msg);
 }
 void ProfileChangerWidget::refreshIcon() {
     QString profileName = this->getProfileName();
@@ -87,15 +85,15 @@ void ProfileChangerWidget::switchProfile() {
 }  
 
 void ProfileChangerWidget::onChangeProfileClicked() {
-//    switchProfile();
-//    refreshIcon();
+    switchProfile();
+    refreshIcon();
 }
 
 void ProfileChangerWidget::onShowSettingsDialog()
 {
-//    SettingsDialog *dialog = new SettingsDialog(0);
-//    connect(dialog, SIGNAL(settingsChanged()), this, SLOT(reloadSettings()));
-//    dialog->show();
+    SettingsDialog *dialog = new SettingsDialog(0);
+    connect(dialog, SIGNAL(settingsChanged()), this, SLOT(reloadSettings()));
+    dialog->show();
 }
 
 void ProfileChangerWidget::reloadSettings()
